==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AssigningCategoryStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
export let AssigningCategoryStyleEventArgsBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningCategoryStyleEventArgsBaseDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a == null) {
                AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
            }
            if (a.k(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningCategoryStyleEventArgsBaseDescriptionMetadata.b(a);
            a.ab("AssigningCategoryStyleEventArgsBase", AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
        }
    }
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningCategoryStyleEventArgsBaseDescriptionMetadata, 'AssigningCategoryStyleEventArgsBaseDescriptionMetadata');
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningCategoryStyleEventArgsBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/AssigningCategoryStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
export let AssigningCategoryStyleEventArgsBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningCategoryStyleEventArgsBaseDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a == null) {
                AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
            }
            if (a.k(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningCategoryStyleEventArgsBaseDescriptionMetadata.b(a);
            a.ad("AssigningCategoryStyleEventArgsBase", AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
        }
    }
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningCategoryStyleEventArgsBaseDescriptionMetadata, 'AssigningCategoryStyleEventArgsBaseDescriptionMetadata');
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningCategoryStyleEventArgsBaseDescriptionMetadata;
})();
